# pyErmine
Estimate Reaction-rates by Markov-based Investigation of Nanoscopy Experiments (ermine) using Python.

## Author
Sebastian Malkusch  

Data Science | Clinical Pharmacology  
Institute for clinical pharmacology  
Goethe-University-Hospital  
Frankfurt am Main  
Germany

## Abstarct
The python package pyErmine analyzes the mobility of laterally diffusing molecules, such as membrane receptors, using hidden Markov models. It maps the movements of individual receptors to discrete diffusion states, all of which are Brownian in nature. The model is trained with single-particle tracking data.

## Requirements
* hmmlearn >= 0.2.4
* numpy >= 1.19.2
* pandas >= 1.1.5
* scikit-learn >= 0.23.2

## Reference
Publication in progress.

## Tutorial
A tutorial including a test data set can be found on Github at the following repository: https://github.com/SMLMS/ermine-tutorial

